package com.zh.project0512.controller.wxApp;

import com.zh.project0512.annotation.TokenValid;
import com.zh.project0512.model.dto.UserPointsRecordListDTO;
import com.zh.project0512.model.vo.UserPointsRecordListVo;
import com.zh.project0512.model.vo.UserPointsVo;
import com.zh.project0512.service.IUserPointsRecordsService;
import com.zh.project0512.utils.JwtUtil;
import com.zh.project0512.utils.result.Result;
import com.zh.project0512.utils.result.ResultPageInfo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

/**
 * 用户积分
 */
@Tag(name = "用户积分")
@RestController
@RequestMapping("/wxApp/userPoints")
public class UserPointsController {
    @Resource
    IUserPointsRecordsService userPointsRecordsService;


    /**
     * 查询用户积分详情
     * @return 用户积分详情
     */
    @Operation(summary = "用户积分详情")
    @PostMapping("/detail")
    @TokenValid
    public Result<UserPointsVo> pointsDetail(@RequestHeader String token){
        String openid = new JwtUtil().parseOpenid(token);
        return Result.success(userPointsRecordsService.pointsDetail(openid),"请求成功");
    }

    /**
     * 查询用户积分记录
     * @param userPointsRecordListDTO 用户积分记录 list DTO
     * @return 用户积分记录 list Vo
     */
    @Operation(summary = "用户积分记录")
    @PostMapping("/list")
    @TokenValid
    public ResultPageInfo<UserPointsRecordListVo> list(@Validated @RequestBody UserPointsRecordListDTO userPointsRecordListDTO,@RequestHeader String token){
        String openid = new JwtUtil().parseOpenid(token);
        return ResultPageInfo.success(userPointsRecordsService.list(userPointsRecordListDTO,openid),"请求成功");
    }

}

